# catchery

Python Error Handler.

## Installation

YouYou can install `catchery` using pip:

```bash
pip install catchery
```

## Usage

Coming soon...

## Development Setup

### Linting with Ruff

This project uses [Ruff](https://beta.ruff.rs/docs/) for linting and code formatting. Ruff is configured via the `pyproject.toml` file in the project root.

To run the linter, execute the following command from the project root:

```bash
ruff check src/catchery/
```

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details.
